(user.video_tutorials)=

# Video Tutorials

This section includes video tutorials that demonstrate various use cases of `bec-widgets`, including video tutorials,
presentations, and conference talks.

## BSEG Meeting 24th July 2024

This video is a presentation of the BEC Widgets project at the BSEG meeting on the 24th July 2024. The presentation
covers the basic interactions, including visualization of live data acquisition and how to steer experiments using
user-friendly tools. Learn how BEC Widgets can enhance your experimental control projects with its intuitive interface
and powerful features.

Used version of BEC Widgets: 0.91.0

<iframe width="560" height="315" src="https://www.youtube.com/embed/qZ8fWXRAdHE" frameborder="0" allowfullscreen></iframe>